Welcome to mirror list, hosted at ThFree Co, Russian Federation.

gitlab.com/gitlab-org/gitlab-foss.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authormicael.bergeron <micaelbergeron@gmail.com>2017-11-22 17:48:09 +0300
committermicael.bergeron <micaelbergeron@gmail.com>2017-12-07 17:01:37 +0300
commitcb6f51ec9b2006f1040cca94119135c92e9a4cd1 (patch)
tree6331c54f8eab568e134c51ec85a0232372471a16 /lib/banzai/object_renderer.rb
parent716f9cbb415cd425644b1aeae19844b26cc7d6b7 (diff)
add support for the commit reference filter
Diffstat (limited to 'lib/banzai/object_renderer.rb')
-rw-r--r--lib/banzai/object_renderer.rb13
1 files changed, 6 insertions, 7 deletions
diff --git a/lib/banzai/object_renderer.rb b/lib/banzai/object_renderer.rb
index 29c4e60f70c..0bf9a8d66bc 100644
--- a/lib/banzai/object_renderer.rb
+++ b/lib/banzai/object_renderer.rb
@@ -17,11 +17,11 @@ module Banzai
# project - A Project to use for redacting Markdown.
# user - The user viewing the Markdown/HTML documents, if any.
- # context - A Hash containing extra attributes to use during redaction
- def initialize(project, user = nil, context = {})
+ # redaction_context - A Hash containing extra attributes to use during redaction
+ def initialize(project, user = nil, redaction_context = {})
@project = project
@user = user
- @context = base_context.merge(context)
+ @redaction_context = base_context.merge(redaction_context)
end
# Renders and redacts an Array of objects.
@@ -48,8 +48,7 @@ module Banzai
pipeline = HTML::Pipeline.new([])
objects.map do |object|
- context = context_for(object, attribute)
- pipeline.to_document(Banzai.render_field(object, attribute, context))
+ pipeline.to_document(Banzai.render_field(object, attribute))
end
end
@@ -74,7 +73,7 @@ module Banzai
# Returns a Banzai context for the given object and attribute.
def context_for(object, attribute)
- @context.merge(object.banzai_render_context(attribute))
+ @redaction_context.merge(object.banzai_render_context(attribute))
end
def base_context
@@ -86,7 +85,7 @@ module Banzai
end
def save_options
- return {} unless @context[:xhtml]
+ return {} unless @redaction_context[:xhtml]
{ save_with: Nokogiri::XML::Node::SaveOptions::AS_XHTML }
end
end